ErrorKind

Enum ErrorKind 

#[non_exhaustive]
pub enum ErrorKind {
Show 17 variants UnexpectedToken { expected: Vec<Expected>, found: String, }, UnexpectedEof { expected: Vec<Expected>, }, UnterminatedString, UnterminatedComment, InvalidEscape { sequence: String, }, InvalidNumber { raw: String, reason: NumberReason, }, EmptyInput, MissingClause { clause: &'static str, after: &'static str, }, DuplicateClause { clause: &'static str, }, InvalidAssignment { reason: &'static str, }, Unsupported { production: Cow<'static, str>, }, Internal { message: String, }, UnresolvedVariable { name: String, }, RedeclaredVariable { name: String, first_span: Span, }, AggregationMix { non_grouping: Vec<String>, }, DistinctNotAllowed, InvalidReference { name: String, reason: &'static str, },
}
The structured kind of a parse/AST error.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


UnexpectedToken

The parser encountered an unexpected token.

Fields

expected: Vec<Expected>
found: String


UnexpectedEof

The input ended before the parser expected it to.

Fields

expected: Vec<Expected>


UnterminatedString

A string literal was opened but never closed.



UnterminatedComment

A comment was opened but never closed.



InvalidEscape

An escape sequence inside a string was invalid.

Fields

sequence: String


InvalidNumber

A numeric literal was malformed.

Fields



EmptyInput

The input was empty.



MissingClause

A required clause was missing after another clause.

Fields

clause: &'static str
after: &'static str


DuplicateClause

A clause appeared more than once where only one is allowed.

Fields

clause: &'static str


InvalidAssignment

An assignment was syntactically or semantically invalid.

Fields

reason: &'static str


Unsupported

A grammar production is not yet supported by the AST builder.

Fields

production: Cow<'static, str>


Internal

An internal error — last-resort fallback.

Fields

message: String


UnresolvedVariable

A variable was referenced but never bound in scope (semantic).

Fields

name: String


RedeclaredVariable

A variable was redeclared in the same scope (semantic).

Fields

name: String
first_span: Span


AggregationMix

WITH/RETURN mixes aggregates and non-grouping expressions (semantic).

Fields

non_grouping: Vec<String>


DistinctNotAllowed

DISTINCT used where it is not allowed (semantic).



InvalidReference

Invalid reference in ORDER BY / WHERE after WITH (semantic).

Fields

name: String
reason: &'static str